@@ -18,16 +18,105 @@
 *
 */
 
+#include <audacious/drct.h>
+#include <audacious/misc.h>
+#include <audacious/plugin.h>
+#include <libaudcore/hook.h>
+
 #include "amidi-plug.h"
 
-InputPlugin *amidiplug_iplist[] = { &amidiplug_ip, NULL };
+static void amidiplug_play_loop (InputPlayback * playback);
 
-DECLARE_PLUGIN(amidi-plug, NULL, NULL, amidiplug_iplist, NULL, NULL, NULL, NULL, NULL);
+static gboolean amidiplug_play (InputPlayback * playback, const gchar *
+ filename_uri, VFSFile * file, gint start_time, gint stop_time, gboolean pause);
+static void amidiplug_pause (InputPlayback * playback, gboolean paused);
+static void amidiplug_mseek (InputPlayback * playback, gint time);
+static Tuple * amidiplug_get_song_tuple (const gchar * filename_uri, VFSFile *
+ file);
 
-static gboolean amidiplug_detect_by_content( gchar * filename_uri , VFSFile * fp )
+AUD_INPUT_PLUGIN
+(
+    .name = "AMIDI-Plug (MIDI Player)",
+    .init = amidiplug_init,
+    .about = amidiplug_aboutbox,
+    .configure = amidiplug_configure,
+    .play = amidiplug_play,
+    .stop = amidiplug_stop,
+    .pause = amidiplug_pause,
+    .mseek = amidiplug_mseek,
+    .get_time = amidiplug_get_time,
+    .get_volume = amidiplug_get_volume,
+    .set_volume = amidiplug_set_volume,
+    .cleanup = amidiplug_cleanup,
+    .probe_for_tuple = amidiplug_get_song_tuple,
+    .file_info_box = amidiplug_file_info_box,
+    .is_our_file_from_vfs = amidiplug_is_our_file_from_vfs,
+    .extensions = amidiplug_vfs_extensions,
+)
+
+static GMutex * init_mutex;
+static gboolean initted;
+
+static GCond * control_cond;
+static gint seek_time;
+
+static GThread * audio_thread;
+static GMutex * audio_control_mutex;
+static GCond * audio_control_cond;
+static gboolean audio_stop_flag, audio_pause_flag;
+static gint audio_seek_time;
+
+static gboolean amidiplug_init (void)
+{
+    init_mutex = g_mutex_new ();
+    initted = FALSE;
+    return TRUE;
+}
+
+static void soft_init (void)
+{
+    g_mutex_lock (init_mutex);
+
+    if (! initted)
+    {
+        amidiplug_gettime_mutex = g_mutex_new ();
+        amidiplug_playing_mutex = g_mutex_new ();
+        control_cond = g_cond_new ();
+
+        audio_control_mutex = g_mutex_new ();
+        audio_control_cond = g_cond_new ();
+
+        i_configure_cfg_ap_read ();
+        i_backend_load (amidiplug_cfg_ap.ap_seq_backend);
+
+        initted = TRUE;
+    }
+
+    g_mutex_unlock (init_mutex);
+}
+
+static void amidiplug_cleanup (void)
+{
+    if (initted)
+    {
+        i_backend_unload ();
+
+        g_mutex_free (amidiplug_gettime_mutex);
+        g_mutex_free (amidiplug_playing_mutex);
+        g_cond_free (control_cond);
+
+        g_mutex_free (audio_control_mutex);
+        g_cond_free (audio_control_cond);
+    }
+
+    g_mutex_free (init_mutex);
+}
+
+static gint amidiplug_is_our_file_from_vfs( const gchar *filename_uri , VFSFile *fp )
 {
   gchar magic_bytes[4];
-  gint res = 0;
+
+  soft_init ();
 
   if ( fp == NULL )
     return FALSE;
@@ -61,67 +150,10 @@ static gboolean amidiplug_detect_by_content( gchar * filename_uri , VFSFile * fp
   return FALSE;
 }
 
-
-static gint amidiplug_is_our_file( gchar * filename_uri )
+static void amidiplug_configure (void)
 {
-  VFSFile * fp;
-  gboolean result = FALSE;
-
-  fp = VFS_FOPEN( filename_uri , "rb" );
-
-  if ( fp == NULL )
-    return FALSE;
-
-  result = amidiplug_detect_by_content( filename_uri , fp );
-  VFS_FCLOSE( fp );
-
-  return result;
-}
-
-
-static gint amidiplug_is_our_file_from_vfs( gchar *filename_uri , VFSFile *fp )
-{
-  return amidiplug_detect_by_content( filename_uri , fp );
-}
-
-
-static void amidiplug_init( void )
-{
-  g_log_set_handler(NULL , G_LOG_LEVEL_WARNING , g_log_default_handler , NULL);
-  
-  amidiplug_gettime_mutex = g_mutex_new();
-  amidiplug_playing_mutex = g_mutex_new();
-  amidiplug_pause_cond = g_cond_new();
-  amidiplug_seekonpause_cond = g_cond_new();
-  
-  DEBUGMSG( "init, read configuration\n" );
-  /* read configuration for amidi-plug */
-  i_configure_cfg_ap_read();
-  amidiplug_playing_status = AMIDIPLUG_STOP;
-  backend.gmodule = NULL;
-  /* load the backend selected by user */
-  i_backend_load( amidiplug_cfg_ap.ap_seq_backend );
-}
-
-
-static void amidiplug_cleanup( void )
-{
-  i_backend_unload(); /* unload currently loaded backend */
-  
-  g_mutex_free(amidiplug_gettime_mutex);
-  g_mutex_free(amidiplug_playing_mutex);
-  g_cond_free(amidiplug_pause_cond);
-  g_cond_free(amidiplug_seekonpause_cond);
-  amidiplug_pause_cond = NULL;
-  amidiplug_seekonpause_cond = NULL;
-}
-
-
-static void amidiplug_configure( void )
-{
-  /* display the nice config dialog */
-  DEBUGMSG( "opening config system\n" );
-  i_configure_gui();
+    soft_init ();
+    i_configure_gui ();
 }
 
 
@@ -131,9 +163,10 @@ static void amidiplug_aboutbox( void )
 }
 
 
-static void amidiplug_file_info_box( gchar * filename_uri )
+static void amidiplug_file_info_box (const gchar * filename)
 {
-  i_fileinfo_gui( filename_uri );
+    soft_init ();
+    i_fileinfo_gui (filename);
 }
 
 
@@ -143,123 +176,46 @@ static void amidiplug_stop( InputPlayback * playback )
 
   g_mutex_lock( amidiplug_playing_mutex );
   amidiplug_playing_status = AMIDIPLUG_STOP;
-  g_cond_signal( amidiplug_pause_cond );
+  g_cond_signal (control_cond);
   g_mutex_unlock( amidiplug_playing_mutex );
-  if ( amidiplug_play_thread )
-  {
-    g_thread_join( amidiplug_play_thread );
-    amidiplug_play_thread = NULL;
-  }
-  if (( backend.autonomous_audio == FALSE ) && ( amidiplug_audio_thread ))
-  {
-    g_thread_join( amidiplug_audio_thread );
-    amidiplug_audio_thread = NULL;
-  }
-  DEBUGMSG( "STOP activated (play thread joined)\n" );
-
-  /* kill the sequencer (while it may have been already killed if coming
-     from pause, it's safe to do anyway since it checks for multiple calls) */
-  if ( backend.gmodule != NULL )
-    backend.seq_off();
-
-  /* call seq_stop */
-  if ( backend.gmodule != NULL )
-    backend.seq_stop();
-
-  /* close audio if current backend works with output plugin */
-  if (( backend.gmodule != NULL ) && ( backend.autonomous_audio == FALSE ))
-  {
-    DEBUGMSG( "STOP activated, closing audio output plugin\n" );
-    playback->output->buffer_free();
-    playback->output->buffer_free();
-    playback->output->close_audio();
-  }
-  /* free midi data (if it has not been freed yet) */
-  i_midi_free( &midifile );
 }
 
-
-static void amidiplug_pause( InputPlayback * playback, gshort paused )
+static void amidiplug_pause (InputPlayback * playback, gboolean paused)
 {
-  if ( paused )
-  {
-    g_mutex_lock( amidiplug_playing_mutex );
-    if ( amidiplug_playing_status == AMIDIPLUG_SEEK )
-    {
-      DEBUGMSG( "handle SEEK ON PAUSE situation\n" , midifile.playing_tick );
-      /* uh oh, we have a pending seek; this can happen when a seek
-         is requested while playback is paused; wait for that seek to
-         be completed before pausing the song again */
-      while ( amidiplug_playing_status != AMIDIPLUG_PLAY )
-        g_cond_wait( amidiplug_seekonpause_cond , amidiplug_playing_mutex );
-    }
-    g_mutex_unlock( amidiplug_playing_mutex );
-    DEBUGMSG( "PAUSE request at tick: %i\n" , midifile.playing_tick );
-    g_mutex_lock( amidiplug_playing_mutex );
-    amidiplug_playing_status = AMIDIPLUG_PAUSE;
-    g_mutex_unlock( amidiplug_playing_mutex );
-    if ( backend.autonomous_audio == FALSE )
-      playback->output->pause(paused);
-  }
-  else
-  {
-    DEBUGMSG( "PAUSE deactivated, resume playing from tick %i\n" , midifile.playing_tick );
-    if ( backend.autonomous_audio == FALSE )
-      playback->output->pause(paused);
-    g_mutex_lock( amidiplug_playing_mutex );
-    amidiplug_playing_status = AMIDIPLUG_PLAY;
-    g_cond_signal( amidiplug_pause_cond );
-    /* wait for unpause operation to be completed */
-    g_cond_wait( amidiplug_pause_cond , amidiplug_playing_mutex );
-    g_mutex_unlock( amidiplug_playing_mutex );
-  }
+    g_mutex_lock (amidiplug_playing_mutex);
+    amidiplug_playing_status = paused ? AMIDIPLUG_PAUSE : AMIDIPLUG_PLAY;
+    g_cond_signal (control_cond);
+    g_cond_wait (control_cond, amidiplug_playing_mutex);
+    g_mutex_unlock (amidiplug_playing_mutex);
 }
 
-
-static void amidiplug_seek( InputPlayback * playback, gint time )
+static void amidiplug_mseek (InputPlayback * playback, gint time)
 {
-  DEBUGMSG( "SEEK requested (time %i)...\n" , time );
-  g_mutex_lock( amidiplug_playing_mutex );
-  midifile.seeking_tick = (gint)((time * 1000000) / midifile.avg_microsec_per_tick);
-  amidiplug_playing_status = AMIDIPLUG_SEEK;
-  g_mutex_unlock( amidiplug_playing_mutex );
-
-  if ( backend.autonomous_audio == FALSE )
-    playback->output->flush(time * 1000);
+    g_mutex_lock (amidiplug_playing_mutex);
+    amidiplug_playing_status = AMIDIPLUG_SEEK;
+    seek_time = time;
+    g_cond_signal (control_cond);
+    g_cond_wait (control_cond, amidiplug_playing_mutex);
+    g_mutex_unlock (amidiplug_playing_mutex);
 }
 
-
-static gint amidiplug_get_time( InputPlayback *playback )
+static gint amidiplug_get_time( InputPlayback * playback )
 {
-  if ( backend.autonomous_audio == FALSE )
-  {
-    g_mutex_lock( amidiplug_playing_mutex );
-    if (( amidiplug_playing_status == AMIDIPLUG_PLAY ) ||
-        ( amidiplug_playing_status == AMIDIPLUG_PAUSE ) ||
-        ( amidiplug_playing_status == AMIDIPLUG_SEEK ) ||
-        (( amidiplug_playing_status == AMIDIPLUG_STOP ) && ( playback->output->buffer_playing() )))
-    {
-      g_mutex_unlock( amidiplug_playing_mutex );
-      return playback->output->output_time();
-    }
-    else if ( amidiplug_playing_status == AMIDIPLUG_STOP )
-    {
-      g_mutex_unlock( amidiplug_playing_mutex );
-      DEBUGMSG( "GETTIME on stopped song, returning -1\n" , time );
-      return -1;
-    }
-    else /* AMIDIPLUG_ERR */
-    {
-      g_mutex_unlock( amidiplug_playing_mutex );
-      DEBUGMSG( "GETTIME on halted song (an error occurred?), returning -1 and stopping the player\n" );
-      audacious_drct_stop();
-      return -1;
-    }
-  }
-  else
-  {
     gint pt;
-    g_mutex_lock( amidiplug_playing_mutex );
+
+    if (! backend.autonomous_audio)
+        return -1;
+
+    g_mutex_lock (amidiplug_playing_mutex);
+
+    if (seek_time != -1)
+    {
+        gint time = seek_time;
+
+        g_mutex_unlock (amidiplug_playing_mutex);
+        return time;
+    }
+
     if (( amidiplug_playing_status == AMIDIPLUG_PLAY ) ||
         ( amidiplug_playing_status == AMIDIPLUG_PAUSE ) ||
         ( amidiplug_playing_status == AMIDIPLUG_SEEK ))
@@ -273,17 +229,16 @@ static gint amidiplug_get_time( InputPlayback *playback )
     else if ( amidiplug_playing_status == AMIDIPLUG_STOP )
     {
       g_mutex_unlock( amidiplug_playing_mutex );
-      DEBUGMSG( "GETTIME on stopped song, returning -1\n" , time );
+      DEBUGMSG( "GETTIME on stopped song, returning -1\n" );
       return -1;
     }
     else /* AMIDIPLUG_ERR */
     {
       g_mutex_unlock( amidiplug_playing_mutex );
-      DEBUGMSG( "GETTIME on halted song (an error occurred?), returning -1 and stopping the player\n" , time );
-      audacious_drct_stop();
+      DEBUGMSG( "GETTIME on halted song (an error occurred?), returning -1 and stopping the player\n" );
+      aud_drct_stop();
       return -1;
     }
-  }
 }
 
 
@@ -309,44 +264,34 @@ static gint amidiplug_set_volume( gint  l , gint  r )
 }
 
 
-static void amidiplug_get_song_info( gchar * filename_uri , gchar ** title , gint * length )
+static Tuple * amidiplug_get_song_tuple (const gchar * filename_uri, VFSFile *
+ file)
 {
   /* song title, get it from the filename */
-  gchar * filename = g_filename_from_uri( filename_uri , NULL , NULL );
-  if ( !filename ) filename = g_strdup( filename_uri );
-  *title = G_PATH_GET_BASENAME(filename_uri);
-  g_free( filename );
+  Tuple *tuple = tuple_new_from_filename(filename_uri);
+  midifile_t mf;
 
-  /* sure, it's possible to calculate the length of a MIDI file anytime,
-     but the file must be entirely parsed to calculate it; this could
-     lead to a bit of performance loss, so let the user decide here */
-  if ( amidiplug_cfg_ap.ap_opts_length_precalc )
-  {
-    /* let's calculate the midi length, using this nice helper function that
-       will return 0 if a problem occurs and the length can't be calculated */
-    midifile_t mf;
+  soft_init ();
 
-    if ( i_midi_parse_from_filename( filename_uri , &mf ) )
-      *length = (gint)(mf.length / 1000);
-    else
-      *length = -1;
+  if ( i_midi_parse_from_filename( filename_uri , &mf ) )
+    tuple_set_int(tuple, FIELD_LENGTH, NULL, mf.length / 1000);
 
-    i_midi_free( &mf );
-  }
-  else
-    *length = -1;
+  i_midi_free( &mf );
 
-  return;
+  return tuple;
 }
 
 
-static void amidiplug_play( InputPlayback * playback )
+static gboolean amidiplug_play (InputPlayback * playback, const gchar *
+ filename_uri, VFSFile * file, gint start_time, gint stop_time, gboolean pause)
 {
-  gchar * filename_uri = playback->filename;
-  gchar * filename = NULL;
+  g_return_val_if_fail (file != NULL, FALSE);
+
   gint port_count = 0;
   gint au_samplerate = -1, au_bitdepth = -1, au_channels = -1;
 
+  soft_init ();
+
   if ( backend.gmodule == NULL )
   {
     g_warning( "No sequencer backend selected\n" );
@@ -356,7 +301,7 @@ static void amidiplug_play( InputPlayback * playback )
                    AMIDIPLUG_MESSAGE_WARN , NULL , TRUE );
     */
     amidiplug_playing_status = AMIDIPLUG_ERR;
-    return;
+    return FALSE;
   }
 
   /* get information about audio from backend, if available */
@@ -378,20 +323,15 @@ static void amidiplug_play( InputPlayback * playback )
   port_count = backend.seq_get_port_count();
   if ( port_count < 1 )
   {
-    g_warning( "No ports selected\n" );
+    aud_interface_show_error (_("You have not selected any sequencer ports for "
+     "MIDI playback.  You can do so in the MIDI plugin preferences."));
     amidiplug_playing_status = AMIDIPLUG_ERR;
-    return;
+    return FALSE;
   }
 
   DEBUGMSG( "PLAY requested, opening file: %s\n" , filename_uri );
-  midifile.file_pointer = VFS_FOPEN( filename_uri , "rb" );
-  if (!midifile.file_pointer)
-  {
-    g_warning( "Cannot open %s\n" , filename_uri );
-    amidiplug_playing_status = AMIDIPLUG_ERR;
-    return;
-  }
-  midifile.file_name = filename_uri;
+  midifile.file_pointer = file;
+  midifile.file_name = g_strdup(filename_uri);
 
   switch( i_midi_file_read_id( &midifile ) )
   {
@@ -441,18 +381,10 @@ static void amidiplug_play( InputPlayback * playback )
       i_midi_setget_length( &midifile );
       DEBUGMSG( "PLAY requested, song length calculated: %i msec\n" , (gint)(midifile.length / 1000) );
 
-
-      /* our length is in microseconds, but the player wants milliseconds */
-      filename = g_filename_from_uri( filename_uri , NULL , NULL );
-      if ( !filename ) filename = g_strdup( filename_uri );
-      playback->set_params( playback , G_PATH_GET_BASENAME(filename) ,
-                             (gint)(midifile.length / 1000) ,
-                             au_bitdepth * au_samplerate * au_channels / 8 ,
-                             au_samplerate , au_channels );
-      g_free( filename );
+      playback->set_params (playback, au_bitdepth * au_samplerate * au_channels
+       / 8, au_samplerate, au_channels);
 
       /* done with file */
-      VFS_FCLOSE( midifile.file_pointer );
       midifile.file_pointer = NULL;
 
       /* play play play! */
@@ -460,7 +392,8 @@ static void amidiplug_play( InputPlayback * playback )
       g_mutex_lock( amidiplug_playing_mutex );
       amidiplug_playing_status = AMIDIPLUG_PLAY;
       g_mutex_unlock( amidiplug_playing_mutex );
-      amidiplug_play_thread = g_thread_self();
+
+      seek_time = -1;
       playback->set_pb_ready(playback);
       amidiplug_play_loop(playback);
       break;
@@ -474,21 +407,128 @@ static void amidiplug_play( InputPlayback * playback )
     }
   }
 
-  if ( midifile.file_pointer )
-  {
-    /* done with file */
-    VFS_FCLOSE( midifile.file_pointer );
-    midifile.file_pointer = NULL;
-  }
+  if (! backend.autonomous_audio)
+      playback->output->close_audio ();
+
+  return TRUE;
 }
 
+static void * audio_loop (void * arg)
+{
+    InputPlayback * playback = arg;
+    gboolean paused = FALSE;
+    void * buffer = NULL;
+    gint buffer_size = 0;
 
+    while (1)
+    {
+        g_mutex_lock (audio_control_mutex);
 
-gpointer amidiplug_play_loop( gpointer arg )
+        if (audio_stop_flag)
+        {
+            g_cond_signal (audio_control_cond);
+            g_mutex_unlock (audio_control_mutex);
+            break;
+        }
+
+        if (audio_seek_time != -1)
+        {
+            playback->output->flush (audio_seek_time);
+            audio_seek_time = -1;
+            g_cond_signal (audio_control_cond);
+        }
+
+        if (audio_pause_flag)
+        {
+            if (! paused)
+            {
+                playback->output->pause (TRUE);
+                paused = TRUE;
+            }
+
+            g_cond_signal (audio_control_cond);
+            g_cond_wait (audio_control_cond, audio_control_mutex);
+            g_mutex_unlock (audio_control_mutex);
+            continue;
+        }
+
+        if (paused)
+        {
+            playback->output->pause (FALSE);
+            paused = FALSE;
+            g_cond_signal (audio_control_cond);
+        }
+
+        g_mutex_unlock (audio_control_mutex);
+
+        if (backend.seq_output (& buffer, & buffer_size))
+            playback->output->write_audio (buffer, buffer_size);
+    }
+
+    g_free (buffer);
+    return NULL;
+}
+
+static void audio_start (InputPlayback * playback)
+{
+    audio_stop_flag = FALSE;
+    audio_pause_flag = FALSE;
+    audio_seek_time = -1;
+    audio_thread = g_thread_create (audio_loop, (void *) playback, TRUE, NULL);
+}
+
+static void audio_seek (gint time)
+{
+    g_mutex_lock (audio_control_mutex);
+    audio_seek_time = time;
+    g_cond_signal (audio_control_cond);
+    g_cond_wait (audio_control_cond, audio_control_mutex);
+    g_mutex_unlock (audio_control_mutex);
+}
+
+static void audio_pause (gboolean pause)
+{
+    g_mutex_lock (audio_control_mutex);
+    audio_pause_flag = pause;
+    g_cond_signal (audio_control_cond);
+    g_cond_wait (audio_control_cond, audio_control_mutex);
+    g_mutex_unlock (audio_control_mutex);
+}
+
+static void audio_stop (void)
+{
+    g_mutex_lock (audio_control_mutex);
+    audio_stop_flag = TRUE;
+    g_cond_signal (audio_control_cond);
+    g_mutex_unlock (audio_control_mutex);
+    g_thread_join (audio_thread);
+}
+
+static void do_seek (gint time)
+{
+    backend.seq_event_allnoteoff (midifile.playing_tick);
+    backend.seq_queue_stop ();
+    amidiplug_skipto (time * (gint64) 1000 / midifile.avg_microsec_per_tick);
+}
+
+static void do_pause (gboolean pause)
+{
+    if (pause)
+    {
+        backend.seq_event_allnoteoff (midifile.playing_tick);
+        backend.seq_queue_stop ();
+    }
+    else
+    {
+        midifile.skip_offset = midifile.playing_tick;
+        backend.seq_queue_start ();
+    }
+}
+
+static void amidiplug_play_loop (InputPlayback * playback)
 {
-  InputPlayback *playback = arg;
   gint j = 0;
-  gboolean rewind = TRUE;
+  gboolean rewind = TRUE, paused = FALSE, stopped = FALSE;
 
   if ( rewind )
   {
@@ -497,8 +537,8 @@ gpointer amidiplug_play_loop( gpointer arg )
       midifile.tracks[j].current_event = midifile.tracks[j].first_event;
   }
 
-  if ( backend.autonomous_audio == FALSE )
-    amidiplug_audio_thread = g_thread_create(amidiplug_audio_loop, playback, TRUE, NULL);
+  if (! backend.autonomous_audio)
+      audio_start (playback);
 
   /* queue start */
   backend.seq_queue_start();
@@ -511,46 +551,69 @@ gpointer amidiplug_play_loop( gpointer arg )
     midievent_t * event = NULL;
     midifile_track_t * event_track = NULL;
     gint i, min_tick = midifile.max_tick + 1;
-    
-    /* check if the song has been paused/seeked/stopped */
-    g_mutex_lock( amidiplug_playing_mutex );
-    if ( amidiplug_playing_status != AMIDIPLUG_PLAY )
+
+    g_mutex_lock (amidiplug_playing_mutex);
+
+    if (amidiplug_playing_status == AMIDIPLUG_STOP)
     {
-      DEBUGMSG( "PLAY thread, PAUSE/SEEK/STOP requested, handle in play loop\n" );
-      if ( amidiplug_playing_status == AMIDIPLUG_PAUSE )
-      {
-        DEBUGMSG( "PLAY thread, PAUSE requested, shut notes and make the play loop wait\n" );
-        backend.seq_event_allnoteoff( midifile.playing_tick );
-        backend.seq_queue_stop();
-        while (( amidiplug_playing_status != AMIDIPLUG_PLAY ) &&
-                ( amidiplug_playing_status != AMIDIPLUG_STOP ))
-          g_cond_wait( amidiplug_pause_cond , amidiplug_playing_mutex );
-        DEBUGMSG( "PLAY thread, UNPAUSE requested, resume playing\n" );
-        g_mutex_lock( amidiplug_gettime_mutex );
-        midifile.skip_offset = midifile.playing_tick;
-        g_mutex_unlock( amidiplug_gettime_mutex );
-        if ( backend.autonomous_audio == FALSE )
-          amidiplug_audio_thread = g_thread_create(amidiplug_audio_loop, playback, TRUE, NULL);
-        backend.seq_queue_start();
-        g_cond_signal( amidiplug_pause_cond );
-      }
-      if ( amidiplug_playing_status == AMIDIPLUG_SEEK )
-      {
-        backend.seq_event_allnoteoff( midifile.playing_tick );
-        backend.seq_queue_stop();
-        amidiplug_skipto( midifile.seeking_tick );
-        midifile.seeking_tick = -1;
-        amidiplug_playing_status = AMIDIPLUG_PLAY;
-        g_cond_signal( amidiplug_seekonpause_cond );
-      }
-      if ( amidiplug_playing_status == AMIDIPLUG_STOP )
-      {
-        DEBUGMSG( "PLAY thread, STOP requested, stopping...\n" );
-        g_mutex_unlock( amidiplug_playing_mutex );  
-        break; /* exit from the for (;;) loop */
-      }
+        g_mutex_unlock (amidiplug_playing_mutex);
+        stopped = TRUE;
+        break;
     }
-    g_mutex_unlock( amidiplug_playing_mutex );    
+
+    if (amidiplug_playing_status == AMIDIPLUG_SEEK)
+    {
+        if (! backend.autonomous_audio)
+            audio_seek (seek_time);
+
+        /* WORKAROUND: wait till unpause to seek */
+        if (! paused)
+        {
+            do_seek (seek_time);
+            seek_time = -1;
+        }
+
+        amidiplug_playing_status = paused ? AMIDIPLUG_PAUSE : AMIDIPLUG_PLAY;
+        g_cond_signal (control_cond);
+    }
+
+    if (amidiplug_playing_status == AMIDIPLUG_PAUSE)
+    {
+        if (! paused)
+        {
+            do_pause (TRUE);
+
+            if (! backend.autonomous_audio)
+                audio_pause (TRUE);
+
+            paused = TRUE;
+            g_cond_signal (control_cond);
+        }
+
+        g_cond_wait (control_cond, amidiplug_playing_mutex);
+        g_mutex_unlock (amidiplug_playing_mutex);
+        continue;
+    }
+
+    if (paused)
+    {
+        do_pause (FALSE);
+
+        if (! backend.autonomous_audio)
+            audio_pause (FALSE);
+
+        /* WORKAROUND (see above) */
+        if (seek_time != -1)
+        {
+            do_seek (seek_time);
+            seek_time = -1;
+        }
+
+        paused = FALSE;
+        g_cond_signal (control_cond);
+    }
+
+    g_mutex_unlock (amidiplug_playing_mutex);
 
     /* search next event */
     for (i = 0; i < midifile.num_tracks; ++i)
@@ -630,16 +693,23 @@ gpointer amidiplug_play_loop( gpointer arg )
     }
   }
 
-  backend.seq_output_shut( midifile.max_tick , midifile.skip_offset );
+  backend.seq_output_shut (stopped ? midifile.playing_tick : midifile.max_tick,
+   midifile.skip_offset);
 
-  g_mutex_lock( amidiplug_playing_mutex );
-  if ( amidiplug_playing_status != AMIDIPLUG_PAUSE )
+  if (! backend.autonomous_audio)
   {
-    amidiplug_playing_status = AMIDIPLUG_STOP;
-    DEBUGMSG( "PLAY thread, song stopped/ended\n" );
+      audio_stop ();
+
+      if (! stopped)
+      {
+          while (playback->output->buffer_playing ())
+              g_usleep (20000);
+      }
   }
-  g_mutex_unlock( amidiplug_playing_mutex );
-  return NULL;
+
+  backend.seq_off ();
+  backend.seq_stop ();
+  i_midi_free (& midifile);
 }
 
 
@@ -745,28 +815,3 @@ void amidiplug_skipto( gint playing_tick )
 
   return;
 }
-
-
-gpointer amidiplug_audio_loop( gpointer arg )
-{
-  InputPlayback *playback = arg;
-  gboolean going = 1;
-  gpointer buffer = NULL;
-  gint buffer_size = 0;
-  while ( going )
-  {
-    if ( backend.seq_output( &buffer , &buffer_size ) )
-    {
-      playback->pass_audio( playback ,
-                     FMT_S16_NE , 2 , buffer_size , buffer , &going );
-    }
-    g_mutex_lock( amidiplug_playing_mutex );
-    if (( amidiplug_playing_status != AMIDIPLUG_PLAY ) &&
-        ( amidiplug_playing_status != AMIDIPLUG_SEEK ))
-      going = FALSE;
-    g_mutex_unlock( amidiplug_playing_mutex );
-  }
-  if ( buffer != NULL )
-    g_free( buffer );
-  return NULL;
-}
