@@ -18,17 +18,20 @@
 *
 */
 
+#include <glib.h>
+#include <string.h>
+
+#include <audacious/drct.h>
+#include <audacious/i18n.h>
+#include <audacious/playlist.h>
+#include <audacious/plugin.h>
+#include <libaudcore/audstrings.h>
+#include <libaudcore/hook.h>
+
 #include "aosd_trigger.h"
 #include "aosd_trigger_private.h"
 #include "aosd_cfg.h"
 #include "aosd_osd.h"
-#include <glib.h>
-#include <audacious/i18n.h>
-#include <audacious/playlist.h>
-#include <audacious/strings.h>
-#include <audacious/hook.h>
-#include <audacious/auddrct.h>
-
 
 extern aosd_cfg_t * global_config;
 
@@ -138,8 +141,7 @@ aosd_trigger_start ( aosd_cfg_osd_trigger_t * cfg_trigger )
   }
   /* When called, this hook will display the text of the user pointer
      or the current playing song, if NULL */
-  aud_hook_register("aosd toggle");
-  aud_hook_associate( "aosd toggle" , aosd_trigger_func_hook_cb , NULL );
+  hook_associate( "aosd toggle" , aosd_trigger_func_hook_cb , NULL );
   return;
 }
 
@@ -148,7 +150,7 @@ void
 aosd_trigger_stop ( aosd_cfg_osd_trigger_t * cfg_trigger )
 {
   gint i = 0;
-  aud_hook_dissociate( "aosd toggle" , aosd_trigger_func_hook_cb );
+  hook_dissociate( "aosd toggle" , aosd_trigger_func_hook_cb );
   for ( i = 0 ; i < cfg_trigger->active->len ; i++ )
   {
     gint trig_code = g_array_index( cfg_trigger->active , gint , i );
@@ -160,11 +162,10 @@ aosd_trigger_stop ( aosd_cfg_osd_trigger_t * cfg_trigger )
 
 /* HELPER FUNCTIONS */
 
-static gchar *
-aosd_trigger_utf8convert ( gchar * str )
+static gchar * aosd_trigger_utf8convert (const gchar * str)
 {
   if ( global_config->osd->text.utf8conv_disable == FALSE )
-    return aud_str_to_utf8( str );
+    return str_to_utf8( str );
   else
     return g_strdup( str );
 }
@@ -173,50 +174,36 @@ aosd_trigger_utf8convert ( gchar * str )
 /* TRIGGER FUNCTIONS */
 
 static void
-aosd_trigger_func_pb_start_onoff ( gboolean turn_on )
+aosd_trigger_func_pb_start_onoff(gboolean turn_on)
 {
-  if ( turn_on == TRUE )
-    aud_hook_associate( "playback begin" , aosd_trigger_func_pb_start_cb , NULL );
+  if (turn_on == TRUE)
+    hook_associate("playback begin", aosd_trigger_func_pb_start_cb, NULL);
   else
-    aud_hook_dissociate( "playback begin" , aosd_trigger_func_pb_start_cb );
+    hook_dissociate("playback begin", aosd_trigger_func_pb_start_cb);
   return;
 }
 
 static void
-aosd_trigger_func_pb_start_cb ( gpointer plentry_gp , gpointer unused )
+aosd_trigger_func_pb_start_cb(gpointer hook_data, gpointer user_data)
 {
-  PlaylistEntry *pl_entry = plentry_gp;
-  if ( plentry_gp != NULL )
-  {
-    gchar *title, *utf8_title;
-    if ( pl_entry->title != NULL )
+    char * title = aud_drct_get_title ();
+
+    if (title != NULL)
     {
-      /* if there is a proper title, use it */
-      title = g_strdup(pl_entry->title);
+        gchar *utf8_title = aosd_trigger_utf8convert(title);
+
+        if (g_utf8_validate(utf8_title, -1, NULL) == TRUE)
+        {
+            gchar *utf8_title_markup = g_markup_printf_escaped(
+                "<span font_desc='%s'>%s</span>", global_config->osd->text.fonts_name[0], utf8_title);
+            aosd_osd_display(utf8_title_markup, global_config->osd, FALSE);
+            g_free(utf8_title_markup);
+        }
+        g_free(utf8_title);
+        str_unref (title);
     }
-    else
-    {
-      /* pick what we have as song title */
-      Playlist *active = aud_playlist_get_active();
-      gint pos = aud_playlist_get_position(active);
-      title = aud_playlist_get_songtitle(active, pos);
-    }
-    utf8_title = aosd_trigger_utf8convert( title );
-    if ( g_utf8_validate( utf8_title , -1 , NULL ) == TRUE )
-    {
-      gchar *utf8_title_markup = g_markup_printf_escaped(
-        "<span font_desc='%s'>%s</span>" , global_config->osd->text.fonts_name[0] , utf8_title );
-      aosd_osd_display( utf8_title_markup , global_config->osd , FALSE );
-      g_free( utf8_title_markup );
-    }
-    g_free( utf8_title );
-    g_free( title );
-  }
-  return;
 }
 
-
-
 typedef struct
 {
   gchar *title;
@@ -224,7 +211,6 @@ typedef struct
 }
 aosd_pb_titlechange_prevs_t;
 
-
 static void
 aosd_trigger_func_pb_titlechange_onoff ( gboolean turn_on )
 {
@@ -235,11 +221,11 @@ aosd_trigger_func_pb_titlechange_onoff ( gboolean turn_on )
     prevs = g_malloc0(sizeof(aosd_pb_titlechange_prevs_t));
     prevs->title = NULL;
     prevs->filename = NULL;
-    aud_hook_associate( "playlist set info" , aosd_trigger_func_pb_titlechange_cb , prevs );
+    hook_associate( "title change" , aosd_trigger_func_pb_titlechange_cb , prevs );
   }
   else
   {
-    aud_hook_dissociate( "playlist set info" , aosd_trigger_func_pb_titlechange_cb );
+    hook_dissociate( "title change" , aosd_trigger_func_pb_titlechange_cb );
     if ( prevs != NULL )
     {
       if ( prevs->title != NULL ) g_free( prevs->title );
@@ -254,21 +240,24 @@ aosd_trigger_func_pb_titlechange_onoff ( gboolean turn_on )
 static void
 aosd_trigger_func_pb_titlechange_cb ( gpointer plentry_gp , gpointer prevs_gp )
 {
-  if ( aud_ip_state->playing )
+  if (aud_drct_get_playing ())
   {
     aosd_pb_titlechange_prevs_t *prevs = prevs_gp;
-    PlaylistEntry *pl_entry = plentry_gp;
+    gint playlist = aud_playlist_get_playing();
+    gint pl_entry = aud_playlist_get_position(playlist);
+    gchar * pl_entry_filename = aud_playlist_entry_get_filename (playlist, pl_entry);
+    gchar * pl_entry_title = aud_playlist_entry_get_title (playlist, pl_entry, FALSE);
 
     /* same filename but title changed, useful to detect http stream song changes */
 
     if ( ( prevs->title != NULL ) && ( prevs->filename != NULL ) )
     {
-      if ( ( pl_entry->filename != NULL ) && ( !strcmp(pl_entry->filename,prevs->filename) ) )
+      if ( ( pl_entry_filename != NULL ) && ( !strcmp(pl_entry_filename,prevs->filename) ) )
       {
-        if ( ( pl_entry->title != NULL ) && ( strcmp(pl_entry->title,prevs->title) ) )
+        if ( ( pl_entry_title != NULL ) && ( strcmp(pl_entry_title,prevs->title) ) )
         {
           /* string formatting is done here a.t.m. - TODO - improve this area */
-          gchar *utf8_title = aosd_trigger_utf8convert( pl_entry->title );
+          gchar *utf8_title = aosd_trigger_utf8convert( pl_entry_title );
           if ( g_utf8_validate( utf8_title , -1 , NULL ) == TRUE )
           {
             gchar *utf8_title_markup = g_markup_printf_escaped(
@@ -278,39 +267,41 @@ aosd_trigger_func_pb_titlechange_cb ( gpointer plentry_gp , gpointer prevs_gp )
           }
           g_free( utf8_title );
           g_free( prevs->title );
-          prevs->title = g_strdup(pl_entry->title);
+          prevs->title = g_strdup(pl_entry_title);
         }
       }
       else
       {
         g_free(prevs->filename);
-        prevs->filename = g_strdup(pl_entry->filename);
+        prevs->filename = g_strdup(pl_entry_filename);
         /* if filename changes, reset title as well */
         if ( prevs->title != NULL )
           g_free(prevs->title);
-        prevs->title = g_strdup(pl_entry->title);
+        prevs->title = g_strdup(pl_entry_title);
       }
     }
     else
     {
       if ( prevs->title != NULL )
         g_free(prevs->title);
-      prevs->title = g_strdup(pl_entry->title);
+      prevs->title = g_strdup(pl_entry_title);
       if ( prevs->filename != NULL )
         g_free(prevs->filename);
-      prevs->filename = g_strdup(pl_entry->filename);
+      prevs->filename = g_strdup(pl_entry_filename);
     }
+
+    str_unref (pl_entry_filename);
+    str_unref (pl_entry_title);
   }
 }
 
-
 static void
 aosd_trigger_func_vol_change_onoff ( gboolean turn_on )
 {
   if ( turn_on == TRUE )
-    aud_hook_associate( "volume set" , aosd_trigger_func_vol_change_cb , NULL );
+    hook_associate( "volume set" , aosd_trigger_func_vol_change_cb , NULL );
   else
-    aud_hook_dissociate( "volume set" , aosd_trigger_func_vol_change_cb );
+    hook_dissociate( "volume set" , aosd_trigger_func_vol_change_cb );
   return;
 }
 
@@ -339,10 +330,10 @@ aosd_trigger_func_vol_change_cb ( gpointer h_vol_gp , gpointer unused )
 {
   gint *h_vol = h_vol_gp;
   static aosd_vol_change_bucket_t bucket = { { 0 , 0 } , 0 };
-  
+
   bucket.h_vol[0] = h_vol[0];
   bucket.h_vol[1] = h_vol[1];
-  
+
   /* in order to avoid repeated display of osd for each volume variation, use a
      timer to prevent it from appearing more than once when multiple volume
      changes are performed in a short time interval (500 msec) */
@@ -365,9 +356,9 @@ static void
 aosd_trigger_func_pb_pauseon_onoff ( gboolean turn_on )
 {
   if ( turn_on == TRUE )
-    aud_hook_associate( "playback pause" , aosd_trigger_func_pb_pauseon_cb , NULL );
+    hook_associate( "playback pause" , aosd_trigger_func_pb_pauseon_cb , NULL );
   else
-    aud_hook_dissociate( "playback pause" , aosd_trigger_func_pb_pauseon_cb );
+    hook_dissociate( "playback pause" , aosd_trigger_func_pb_pauseon_cb );
   return;
 }
 
@@ -386,42 +377,40 @@ static void
 aosd_trigger_func_pb_pauseoff_onoff ( gboolean turn_on )
 {
   if ( turn_on == TRUE )
-    aud_hook_associate( "playback unpause" , aosd_trigger_func_pb_pauseoff_cb , NULL );
+    hook_associate( "playback unpause" , aosd_trigger_func_pb_pauseoff_cb , NULL );
   else
-    aud_hook_dissociate( "playback unpause" , aosd_trigger_func_pb_pauseoff_cb );
+    hook_dissociate( "playback unpause" , aosd_trigger_func_pb_pauseoff_cb );
   return;
 }
 
 static void
 aosd_trigger_func_pb_pauseoff_cb ( gpointer unused1 , gpointer unused2 )
 {
-  Playlist *active = aud_playlist_get_active();
+  gint active = aud_playlist_get_active();
   gint pos = aud_playlist_get_position(active);
-  gchar *title, *utf8_title, *utf8_title_markup;
+  gchar *utf8_title, *utf8_title_markup;
   gint time_cur, time_tot;
   gint time_cur_m, time_cur_s, time_tot_m, time_tot_s;
 
-  time_tot = aud_playlist_get_songtime(active, pos) / 1000;
-  time_cur = audacious_drct_get_time() / 1000;
+  time_tot = aud_playlist_entry_get_length (active, pos, FALSE) / 1000;
+  time_cur = aud_drct_get_time() / 1000;
   time_cur_s = time_cur % 60;
   time_cur_m = (time_cur - time_cur_s) / 60;
   time_tot_s = time_tot % 60;
   time_tot_m = (time_tot - time_tot_s) / 60;
 
-  title = aud_playlist_get_songtitle(active, pos);
-  utf8_title = aosd_trigger_utf8convert( title );
+  utf8_title = aud_playlist_entry_get_title (active, pos, FALSE);
   utf8_title_markup = g_markup_printf_escaped(
     "<span font_desc='%s'>%s (%i:%02i/%i:%02i)</span>" ,
     global_config->osd->text.fonts_name[0] , utf8_title , time_cur_m , time_cur_s , time_tot_m , time_tot_s );
   aosd_osd_display( utf8_title_markup , global_config->osd , FALSE );
   g_free( utf8_title_markup );
-  g_free( utf8_title );
-  g_free( title );
+  str_unref (utf8_title);
   return;
 }
 
 
-/* Call with aud_hook_call("aosd toggle", param);
+/* Call with hook_call("aosd toggle", param);
    If param != NULL, display the supplied text in the OSD
    If param == NULL, display the current playing song */
 static void
@@ -433,13 +422,7 @@ aosd_trigger_func_hook_cb ( gpointer markup_text , gpointer unused )
     aosd_osd_display( markup_text , global_config->osd , FALSE );
   } else {
     /* Display currently playing song */
-    Playlist* pl;
-    PlaylistEntry *pl_entry;
-
-    pl = aud_playlist_get_active();
-    if (pl == NULL) return;
-    pl_entry = aud_playlist_get_entry_to_play(pl);
-    aosd_trigger_func_pb_start_cb ( (void*)pl_entry, NULL );
+    aosd_trigger_func_pb_start_cb (NULL, NULL);
   }
   return;
 }
