@@ -18,8 +18,6 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses>.
  */
 
-#include "config.h"
-
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -32,6 +30,16 @@
 #include <cdio/audio.h>
 #include <cdio/sector.h>
 #include <cdio/cd_types.h>
+
+/* libcdio's header files #define these */
+#undef PACKAGE
+#undef PACKAGE_BUGREPORT
+#undef PACKAGE_NAME
+#undef PACKAGE_STRING
+#undef PACKAGE_TARNAME
+#undef PACKAGE_VERSION
+#undef VERSION
+
 #include <cddb/cddb.h>
 
 #include <glib.h>
@@ -46,6 +54,7 @@
 #include <libaudgui/libaudgui-gtk.h>
 
 #include "cdaudio-ng.h"
+#include "config.h"
 #include "configure.h"
 
 #define MAX_RETRIES 10
