@@ -25,6 +25,7 @@
 #include <stdlib.h>
 #include <stdarg.h>
 
+#include <audacious/debug.h>
 #include <libaudcore/audstrings.h>
 
 #include "xs_config.h"
@@ -59,15 +60,15 @@ void xs_error(const gchar *fmt, ...)
     va_end(ap);
 }
 
-#ifdef DEBUG
 void XSDEBUG(const gchar *fmt, ...)
 {
     va_list ap;
     va_start(ap, fmt);
-    g_logv("AUD-SID", G_LOG_LEVEL_DEBUG, fmt, ap);
+    char * str = g_strdup_vprintf (fmt, ap);
+    AUDDBG ("%s", str);
+    g_free (str);
     va_end(ap);
 }
-#endif
 
 
 /*
@@ -489,6 +490,7 @@ static void xs_fill_subtunes(Tuple *tuple, xs_tuneinfo_t *info)
 
     for (found = count = 0; count < info->nsubTunes; count++) {
         if (count + 1 == info->startTune || !xs_cfg.subAutoMinOnly ||
+            info->subTunes[count].tuneLength < 0 ||
             info->subTunes[count].tuneLength >= xs_cfg.subAutoMinTime)
             subtunes[found ++] = count + 1;
     }
@@ -526,7 +528,7 @@ Tuple * xs_probe_for_tuple(const gchar *filename, xs_file_t *fd)
 
     xs_get_song_tuple_info(tuple, info, tune);
 
-    if (xs_cfg.subAutoEnable && info->nsubTunes > 1 && tune < 0)
+    if (xs_cfg.subAutoEnable && info->nsubTunes > 1 && ! tune)
         xs_fill_subtunes(tuple, info);
 
     xs_tuneinfo_free(info);
