@@ -40,7 +40,6 @@ gchar * skins_paths[SKINS_PATH_COUNT];
 
 static gboolean skins_init (void);
 static void skins_cleanup (void);
-static void skins_about (void);
 static gboolean ui_is_shown (void);
 static gboolean ui_is_focused (void);
 static void show_error_message (const gchar * text);
@@ -50,7 +49,6 @@ AUD_IFACE_PLUGIN
     .name = "Winamp Classic Interface",
     .init = skins_init,
     .cleanup = skins_cleanup,
-    .about = skins_about,
     .configure = skins_configure,
     .show = mainwin_show,
     .is_shown = ui_is_shown,
@@ -157,15 +155,6 @@ static void skins_cleanup (void)
     }
 }
 
-static void skins_about (void)
-{
-    static GtkWidget * about_window = NULL;
-
-    audgui_simple_message (& about_window, GTK_MESSAGE_INFO,
-     _("About Skinned GUI"),
-     _("Copyright (c) 2008, by Tomasz Moń <desowin@gmail.com>\n\n"));
-}
-
 static gboolean ui_is_shown (void)
 {
     return config.player_visible;
