@@ -2,7 +2,7 @@
  * Audacious: A cross-platform multimedia player
  * Copyright (c) 2006 William Pitcock, Tony Vroon, George Averill,
  *                    Giacomo Lozito, Derek Pomery, Yoshiki Yazawa
- *                    and Matti Hmlinen.
+ *                    and Matti Hämäläinen.
  * Copyright (c) 2011 John Lindgren
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,6 +20,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#include <glib.h>
+#include <string.h>
+
 #include <libxml/tree.h>
 #include <libxml/parser.h>
 #include <libxml/xmlreader.h>
@@ -54,10 +57,9 @@ static const xspf_entry_t xspf_entries[] = {
     { FIELD_QUALITY,      "quality",      TUPLE_STRING,   TRUE},
 
     { FIELD_CODEC,        "codec",        TUPLE_STRING,   TRUE},
-    { FIELD_SONG_ARTIST,  "song-artist",  TUPLE_STRING,   TRUE},
 
-    { FIELD_MTIME,        "mtime",        TUPLE_INT,      TRUE},
-    { FIELD_FORMATTER,    "formatter",    TUPLE_STRING,   TRUE},
+    { FIELD_SONG_ARTIST,  "song-artist",  TUPLE_STRING,   TRUE},
+    { FIELD_COMPOSER,     "composer",     TUPLE_STRING,   TRUE},
     { FIELD_PERFORMER,    "performer",    TUPLE_STRING,   TRUE},
     { FIELD_COPYRIGHT,    "copyright",    TUPLE_STRING,   TRUE},
     { FIELD_DATE,         "date",         TUPLE_STRING,   TRUE},
@@ -80,7 +82,7 @@ static const xspf_entry_t xspf_entries[] = {
 static const gint xspf_nentries = (sizeof(xspf_entries) / sizeof(xspf_entries[0]));
 
 static void xspf_add_file (xmlNode * track, const gchar * filename, const gchar
- * base, struct index * filenames, struct index * tuples)
+ * base, Index * filenames, Index * tuples)
 {
     xmlNode *nptr;
     gchar *location = NULL;
@@ -93,22 +95,22 @@ static void xspf_add_file (xmlNode * track, const gchar * filename, const gchar
                 gchar *str = (gchar *)xmlNodeGetContent(nptr);
 
                 if (strstr (str, "://") != NULL)
-                    location = g_strdup (str);
+                    location = str_get (str);
                 else if (str[0] == '/' && base != NULL)
                 {
                     const gchar * colon = strstr (base, "://");
 
                     if (colon != NULL)
-                        location = g_strdup_printf ("%.*s%s", (gint) (colon + 3
-                         - base), base, str);
+                        location = str_printf ("%.*s%s", (gint) (colon + 3 -
+                         base), base, str);
                 }
                 else if (base != NULL)
                 {
                     const gchar * slash = strrchr (base, '/');
 
                     if (slash != NULL)
-                        location = g_strdup_printf ("%.*s%s", (gint) (slash + 1
-                         - base), base, str);
+                        location = str_printf ("%.*s%s", (gint) (slash + 1 -
+                         base), base, str);
                 }
 
                 xmlFree(str);
@@ -134,13 +136,13 @@ static void xspf_add_file (xmlNode * track, const gchar * filename, const gchar
                         case TUPLE_STRING:
                             if (! tuple)
                                 tuple = tuple_new ();
-                            tuple_associate_string(tuple, xspf_entries[i].tupleField, NULL, (gchar *)str);
+                            tuple_set_str(tuple, xspf_entries[i].tupleField, NULL, (gchar *)str);
                             break;
 
                         case TUPLE_INT:
                             if (! tuple)
                                 tuple = tuple_new ();
-                            tuple_associate_int(tuple, xspf_entries[i].tupleField, NULL, atol((char *)str));
+                            tuple_set_int(tuple, xspf_entries[i].tupleField, NULL, atol((char *)str));
                             break;
 
                         default:
@@ -164,12 +166,12 @@ static void xspf_add_file (xmlNode * track, const gchar * filename, const gchar
         index_append(tuples, tuple);
     }
     else if (tuple)
-        tuple_free (tuple);
+        tuple_unref (tuple);
 }
 
 
 static void xspf_find_track (xmlNode * tracklist, const gchar * filename, const
- gchar * base, struct index * filenames, struct index * tuples)
+ gchar * base, Index * filenames, Index * tuples)
 {
     xmlNode *nptr;
 
@@ -196,7 +198,7 @@ static gint close_cb (void * file)
 }
 
 static gboolean xspf_playlist_load (const gchar * filename, VFSFile * file,
- gchar * * title, struct index * filenames, struct index * tuples)
+ gchar * * title, Index * filenames, Index * tuples)
 {
     xmlDoc * doc = xmlReadIO (read_cb, close_cb, file, filename, NULL,
      XML_PARSE_RECOVER);
@@ -225,8 +227,8 @@ static gboolean xspf_playlist_load (const gchar * filename, VFSFile * file,
                     xmlChar * xml_title = xmlNodeGetContent (nptr2);
                     if (xml_title && xml_title[0])
                     {
-                        g_free (* title);
-                        * title = g_strdup ((gchar *) xml_title);
+                        str_unref (* title);
+                        * title = str_get ((gchar *) xml_title);
                     }
                     xmlFree (xml_title);
                 }
@@ -347,7 +349,7 @@ static void xspf_add_node(xmlNodePtr node, TupleValueType type,
 
 
 static gboolean xspf_playlist_save (const gchar * filename, VFSFile * file,
- const gchar * title, struct index * filenames, struct index * tuples)
+ const gchar * title, Index * filenames, Index * tuples)
 {
     gint entries = index_count (filenames);
     xmlDocPtr doc;
@@ -376,7 +378,7 @@ static gboolean xspf_playlist_save (const gchar * filename, VFSFile * file,
         const gchar * filename = index_get (filenames, count);
         const Tuple * tuple = index_get (tuples, count);
         xmlNodePtr track, location;
-        const gchar *scratch = NULL;
+        gchar *scratch = NULL;
         gint scratchi = 0;
 
         track = xmlNewNode(NULL, (xmlChar *)"track");
@@ -396,9 +398,10 @@ static gboolean xspf_playlist_save (const gchar * filename, VFSFile * file,
 
                 switch (xs->type) {
                     case TUPLE_STRING:
-                        scratch = tuple_get_string (tuple, xs->tupleField, NULL);
+                        scratch = tuple_get_str (tuple, xs->tupleField, NULL);
                         if (! scratch)
                             isOK = FALSE;
+                        str_unref(scratch);
                         break;
                     case TUPLE_INT:
                         scratchi = tuple_get_int (tuple, xs->tupleField, NULL);
